<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar_SA">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About iTALC</source>
        <translation>حول &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>About</source>
        <translation>حول</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>المؤلفون</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>ترجمة </translation>
    </message>
    <message>
        <source>Current language not translated yet (or native English).

If you&apos;re interested in translating iTALC into your local or another language or want to improve an existing translation, please contact an iTALC developer!</source>
        <translation>لم تتم ترجمة اللغة الحالية بعد (أو اللغة الأم هي الإنجليزية)‏
إذا رغبت في ترجمة &quot;آيتالك&quot; إلى لغتك المحلية أو لغة أخرى أو إذا رغبت في تحسين الترجمة الحالية، يرجى الإتصال بمطور &quot;آيتالك&quot; !‏</translation>
    </message>
    <message>
        <source>License</source>
        <translation>ترخيص</translation>
    </message>
    <message>
        <source>iTALC - Intelligent Teaching And Learning with Computers

Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
        <translation type="unfinished">‏&quot;آيتالك&quot; - التعليم والتعلم الذكي بواسطة الحاسب {2004-2013 ?}</translation>
    </message>
</context>
<context>
    <name>AccessDialogSlave</name>
    <message>
        <source>Never for this session</source>
        <translation>ليس لهذه الحلقة </translation>
    </message>
    <message>
        <source>Always for this session</source>
        <translation>دائما لهذه الحلقة </translation>
    </message>
    <message>
        <source>Confirm desktop access</source>
        <translation>تأكيد أمكانية الوصول لسطح المكتب</translation>
    </message>
    <message>
        <source>The user %1 at host %2 wants to access your desktop. Do you want to grant access?</source>
        <translation>المستخدم 1% عند  المضيف 2% يريد الوصول إلى سطح مكتبك. هل ترغب في منح صلاحية الوصول؟</translation>
    </message>
</context>
<context>
    <name>ClassroomManager</name>
    <message>
        <source>Classroom-Manager</source>
        <translation>مدير - غرفة الدراسة </translation>
    </message>
    <message>
        <source>Use this workspace to manage your computers and classrooms in an easy way.</source>
        <translation>استخدم مكان العمل هذا لإدارة حاسباتك وغرف الدراسة بطريقة سهلة </translation>
    </message>
    <message>
        <source>This is where computers and classrooms are managed. You can add computers or classrooms by clicking right in this list.</source>
        <translation>هنا تتم إدارة الحاسبات وغرف الدراسة. يمكنك إضافة حاسبات وغرف دراسة بالنقر على يمين هذه القائمة </translation>
    </message>
    <message>
        <source>Classrooms/computers</source>
        <translation>غرف دراسة/ حاسبات</translation>
    </message>
    <message>
        <source>IP-address</source>
        <translation>عنوان آي بيه</translation>
    </message>
    <message>
        <source>Usernames</source>
        <translation>أسماء المستخدمين</translation>
    </message>
    <message>
        <source>Show usernames</source>
        <translation>عرض أسماء المستخدمين</translation>
    </message>
    <message>
        <source>Use the context-menu (right mouse-button) to add/remove computers and/or classrooms.</source>
        <translation>استخدم قائمة السياق (زر الفأرة الأيمن) لإضافة أو إزالة الحاسبات او غرف الدراسة</translation>
    </message>
    <message>
        <source>Export to text-file</source>
        <translation>تصدير إلى ملف نصي </translation>
    </message>
    <message>
        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes necessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
        <translation>استخدم هذا الزر لتصدير قائمة الحاسبات وأسماء المستخدمين الحالية إلى ملف نصي. يمكنك استخدام هذا الملف لاحقا لجمع الملفات بعد إنتهاء الإختبار. يكون هذا الإجراء ضروريا، في بعض الأحيان، إذ أن بعض المستخدمين قد </translation>
    </message>
    <message>
        <source>Hide teacher computers</source>
        <translation>إخفاء حاسب المعلِّم</translation>
    </message>
    <message>
        <source>Show/hide</source>
        <translation>عرض أو إخفاء</translation>
    </message>
    <message>
        <source>Edit settings</source>
        <translation>تحرير الإعدادات</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>إزالة </translation>
    </message>
    <message>
        <source>Show all computers in classroom</source>
        <translation>عرض كافة الحاسبات في غرفة الدراسة  </translation>
    </message>
    <message>
        <source>Hide all computers in classroom</source>
        <translation>إخفاء كافة الحاسبات في غرفة الدراسة </translation>
    </message>
    <message>
        <source>Edit name</source>
        <translation>تحرير الاسم</translation>
    </message>
    <message>
        <source>Remove classroom</source>
        <translation>إزالة غرفة دراسة </translation>
    </message>
    <message>
        <source>Add computer</source>
        <translation>إضافة حاسب</translation>
    </message>
    <message>
        <source>Add classroom</source>
        <translation>إضافة غرفة دراسة</translation>
    </message>
    <message>
        <source>No configuration-file found</source>
        <translation>تعذر العثور على ملف التهيئة </translation>
    </message>
    <message>
        <source>Could not open configuration file %1.
You will have to add at least one classroom and computers using the classroom-manager which you&apos;ll find inside the program in the sidebar on the left side.</source>
        <translation>تعذر فتح ملف تهيئة 1%‏
يلزم إضافة غرفة دراسة واحدة على الأقل وحاسبات باستخدام واجهة مدير غرفة الدراسة التي يمكنك الوصول إليها من الشريط الجانبي الأيسر </translation>
    </message>
    <message>
        <source>Error in configuration-file</source>
        <translation>خطأ في ملف التهيئة </translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file and have to add all classrooms and computers again.</source>
        <translation>حدث خطأ أثناء التحليل اللغوي لملف التهيئة 1%‏ 
يرجى تحريره وإلا سيلزم حذف هذا الملف وسيتعين عليك إضافة كافة غرف الدراسة والحاسبات مرة أخرى.‏  </translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file.</source>
        <translation>حدث خطأ أثناء التحليل اللغوي لملف التهيئة 1%‏ 
يرجى تحريره وإلا سيلزم حذف الملف </translation>
    </message>
    <message>
        <source>Select output-file</source>
        <translation>إختيار ملف الخرج</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>(*.txt) ملفات نصية</translation>
    </message>
    <message>
        <source>Actions for selected</source>
        <translation>عمليات لـلمختار</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>عمليات</translation>
    </message>
    <message>
        <source>Actions for %1</source>
        <translation>عمليات لـ 1%‏</translation>
    </message>
    <message>
        <source>New name for classroom</source>
        <translation>اسم جديد لغرفة الدراسة </translation>
    </message>
    <message>
        <source>Please enter a new name for classroom &quot;%1&quot;.</source>
        <translation>يرجى إدخال اسم جديد لغرفة الدراسة &quot;1%&quot;.‏</translation>
    </message>
    <message>
        <source>Are you sure want to remove classroom &quot;%1&quot;?
All computers in it will be removed as well!</source>
        <translation>هل ترغب فعلا في إزالة غرفة الدراسة &quot;1%&quot;؟
ستتم أيضا إزالة كافة الحاسبات التي بالغرفة</translation>
    </message>
    <message>
        <source>Missing classroom</source>
        <translation>غرفة دراسة مفقودة</translation>
    </message>
    <message>
        <source>Before adding computers you have to create at least one classroom.
Do you want to create a new classrom now?</source>
        <translation>قبل إضافة حاسب، يلزم إنشاء غرفة دراسة
هل ترغب في إنشاء غرفة دراسة الآن؟</translation>
    </message>
    <message>
        <source>New classroom</source>
        <translation>غرفة دراسة جديدة</translation>
    </message>
    <message>
        <source>Please enter the name of the classroom you want to create.</source>
        <translation>يرجى إدخال اسم غرفة الدراسة التي ترغب في إنشائها.‏</translation>
    </message>
</context>
<context>
    <name>Client</name>
    <message>
        <source>Unknown state</source>
        <translation>حالة غير معروفة </translation>
    </message>
    <message>
        <source>No user logged in</source>
        <translation>لم يسجل مستخدم دخول على النظام </translation>
    </message>
    <message>
        <source>Host unreachable</source>
        <translation>لا يمكن الوصول إلى الجهاز المضيف </translation>
    </message>
    <message>
        <source>Demo running</source>
        <translation>تشغيل العرض التعريفي</translation>
    </message>
    <message>
        <source>Desktop locked</source>
        <translation>سطح المكتب مغلق</translation>
    </message>
</context>
<context>
    <name>ClientAction</name>
    <message>
        <source>Are you sure want logout all users on all visible computers ?</source>
        <translation>هل ترغب فعلا في إخراج كافة المستخدمين من كافة الحاسبات الظاهرة </translation>
    </message>
    <message>
        <source>Are you sure want logout all users on all selected computers ?</source>
        <translation>هل ترغب فعلا في إخراج كافة المستخدمين من كافة الحاسبات المختارة </translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation>إخراج المستخدم</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all visible computers?</source>
        <translation>هل ترغب فعلا في إعادة تشغيل كافة الحاسبات الظاهرة  </translation>
    </message>
    <message>
        <source>Are you sure want to reboot all selected computers?</source>
        <translation>هل ترغب فعلا في إعادة تشغيل كافة الحاسبات المختارة  </translation>
    </message>
    <message>
        <source>Reboot computers</source>
        <translation>إعادة تشغيل الحاسبات </translation>
    </message>
    <message>
        <source>Are you sure want to power down all visible computers?</source>
        <translation>هل ترغب فعلا في إغلاق كافة الحاسبات الظاهرة  </translation>
    </message>
    <message>
        <source>Are you sure want to power down all selected computers?</source>
        <translation>هل ترغب فعلا في إغلاق كافة الحاسبات المختارة  </translation>
    </message>
</context>
<context>
    <name>ClientSettingsDialog</name>
    <message>
        <source>Invalid MAC-address</source>
        <translation>عنوان ماك غير صحيح</translation>
    </message>
    <message>
        <source>You specified an invalid MAC-address. Either leave the field blank or enter a valid MAC-address (use &quot;:&quot; as separator!).</source>
        <translation>لقد أدخلت عنوان ماك غير صحيح. أترك الحقل خاليا أو أدخل عنوان ماك صحيح (استخدم علامة &quot;:&quot; كفاصل)‏ </translation>
    </message>
    <message>
        <source>Client settings</source>
        <translation>إعدادات الحاسب الفرعي</translation>
    </message>
    <message>
        <source>IP/hostname</source>
        <translation>عنوانIP أو اسم المضيف</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;enter an IP-address or hostname under which iTALC can reach the client (use &apos;:&apos; for specifying an optional port-number)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>قم بادخال عنوانIP أو اسم مضيف يمكن لنظام &quot;آيتالك&quot; من خلاله الوصول إلى الحاسب الفرعي (استخدم العلامة &quot;:&quot; لتعريف رقم منفذ إختياري).</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Optional nickname of the host which is displayed in iTALC.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>كنية إختيارية للمضيف تعرض على نظام &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>MAC address</source>
        <translation>IPعنوان</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hardware/MAC-address of client - only used for powering on client&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>عنوان ماك لجهاز الحاسب الفرعي - يستخدم فقط لتشغيل الحاسب الفرعي</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation>غرفة دراسة</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>Student computer</source>
        <translation>حاسب الطالب</translation>
    </message>
    <message>
        <source>Teacher computer</source>
        <translation>حاسب المدرِّس</translation>
    </message>
    <message>
        <source>Other/undefined computer</source>
        <translation>حاسب آخرغير معرّف</translation>
    </message>
    <message>
        <source>Missing IP address/hostname</source>
        <translation>عنوان IP أو مضيف مفقود</translation>
    </message>
    <message>
        <source>You didn&apos;t specify an IP address or hostname for the computer!</source>
        <translation>لم تحدد عنوان IP أو مضيف لهذا الحاسب</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <source>Interval between updates</source>
        <translation>الفترات الفاصلة بين التحديثات</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set the interval between updates of clients. Higher values result in lower network-traffic and lower CPU-usage on this computer.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>يمكنك هنا ضبط الفترة الفاصلة بين عمليات تحديث الأجهزة الفرعية. القيم العالية يترتب عليها حركة أقل على الشبكة واستخدام أقل لمعالج هذا الحاسب </translation>
    </message>
    <message>
        <source> seconds</source>
        <translation>ثواني</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>واجهة المستخدم</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show balloon-tooltips for toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>عدم إظهار تلميحات بالونية لازر شريط الأدوات</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Check this option if you&apos;re annoyed by the balloon-tooltips appearing when moving mouse-cursor over toolbar-buttons.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>أشِّرعلى هذا الخيار إن كنت لا ترغب في ظهور تلميحات بالونية عن تمرير مؤشر الفأرة فوق لازر شريط الأدوات</translation>
    </message>
    <message>
        <source>No balloon-tooltips</source>
        <translation>تعطيل تلميحات البالونة</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show texts on toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>عدم إظهار النصوص على لازر شريط الأدوات</translation>
    </message>
    <message>
        <source>No texts on toolbar-buttons</source>
        <translation>تعطيل النصوص على أزر شريط الادوات </translation>
    </message>
    <message>
        <source>Your role (needs according keys!)</source>
        <translation>دورك (الحاجة وفق المفاتيح)‏</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can select your role. Only change this if you know what you&apos;re doing. Otherwise you won&apos;t be able to access any clients until you restore your old role.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>يمكنك هنا إختيار دورك. قم بتغيير هذا الاعداد فقط إن كنت تعرف ما تفعله؛ وإلا سوف لن تتمكن من الوصول الى أي أجهزة فرعية حتى تستعيد دورك القديم.  </translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation>مدرِّس</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation>المدير</translation>
    </message>
    <message>
        <source>Supporter</source>
        <translation>معاون</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>أخرى</translation>
    </message>
    <message>
        <source>Settings for multi-logon</source>
        <translation>إعدادات للدخول المتعدد</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>النطاق</translation>
    </message>
    <message>
        <source>Double-click action for client-window</source>
        <translation>النقر المزدوج على نافذة حاسب فرعي</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set what should happen if you double-click a client-window.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>يمكنك هنا تحديد ما سيحدث في حالة النقر المزدوج على نافذة حاسب فرعي</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>تحكم من بُعد</translation>
    </message>
    <message>
        <source>View live in fullscreen</source>
        <translation>معاينة حيّة ملء الشاشة</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Please note, that some changes won&apos;t take effect until you restart iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>يرجى ملاحظة أن بعض التغييرات لن يتم تفعيلها إلا بعد إعادة تشغيل نظام &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ar - العربية</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cs - Česky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>de - Deutsch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>el - Ελληνικά</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>es - Español</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fi - Suomi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fr - Français</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>he - עִבְרִית</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hu - Magyar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>it - Italiano</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nl - Nederlands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nn - Norsk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pl - Polski</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_br - Brasileiro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_pt - Português</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ru - Русский</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sk - Slovenský</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sl - Slovenčina</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sv - Svenska</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tr - Türkçe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>uk - Українська</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_cn - 简体字</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_tw - 簡體字</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Your iTALC-configuration</source>
        <translation>تهيئة نظام &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>In this workspace you can customize iTALC to fit your needs.</source>
        <translation>على هذه الشاشة يمكنك تخصيص &quot;آيتالك&quot; وفق إحتياجاتك</translation>
    </message>
</context>
<context>
    <name>DecoratedMessageBox</name>
    <message>
        <source>OK</source>
        <translation>موافق</translation>
    </message>
</context>
<context>
    <name>DemoClient</name>
    <message>
        <source>iTALC Demo</source>
        <translation>عرض تعريفي لـ &quot;آيتالك&quot;‏</translation>
    </message>
</context>
<context>
    <name>ItalcCoreServer</name>
    <message>
        <source>Authentication error</source>
        <translation>خطأ في عملية التوثيق</translation>
    </message>
    <message>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translation>حاول أحد ( 1IP%) الوصول إلى هذا الحاسب ولكن لم يتمكن من توثيق هويته بنجاح</translation>
    </message>
</context>
<context>
    <name>ItalcVncConnection</name>
    <message>
        <source>VNC authentication failed because of too many authentication tries.</source>
        <translation>ثعذر التحقق بسبب كثرة المحاولات.</translation>
    </message>
    <message>
        <source>VNC authentication failed.</source>
        <translation>أخفقت عملية توثيق الدخول بسبب المحاولات المتعددة .‏</translation>
    </message>
    <message>
        <source>VNC server closed connection.</source>
        <translation>قام خادم شبكة الحوسبة الإلكترونية بقطع التوصيل</translation>
    </message>
</context>
<context>
    <name>KeyFileAssistant</name>
    <message>
        <source>iTALC Access Key Assistant</source>
        <translation>مساعد مفتاح وصول &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>Create/import iTALC access keys</source>
        <translation>إنشاء أو استيراد مفاتيح وصول لـ &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>This assistant will help you to create or import iTALC access keys.</source>
        <translation>سيقوم المساعد بمساعدتك في إنشاء او استيراد مفتاح وصول لنظام &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>How does it work?</source>
        <translation>كيف يعمل؟</translation>
    </message>
    <message>
        <source>iTALC access keys consist of two parts belonging together, a private and a public key part.

Using the private key part, users on the master computer will be able to access client computers. It is important that only authorized users have read access to the private key file.

The public key part is used on the client computers to verify that any incoming connection request is authorized.</source>
        <translation>يتألف مفتاح وصول &quot;آيتالك&quot; من جزئين مترابطين، جزء خاص وجزء عام
باستخدام الجزء الخاص من المفتاح، يمكن لمستخدم الحاسب الرئيسي الوصول إلى الحاسب الفرعي. من الضروري منح صلاحية قراءة ملف المفاتيح الخاصة فقط للمستخدمين المصرح لهم.   
يستخدم الجزء العام من المفتاح على الحاسب الفرعي للتأكد من أن أي طلب اتصال وارد مصرح به </translation>
    </message>
    <message>
        <source>Assistant mode</source>
        <translation>حالة المساعد</translation>
    </message>
    <message>
        <source>Please choose whether to create new access keys or import a public key on a client.</source>
        <translation>يرجى إختيار إما إنشاء مفاتيح وصول جديدة أو استيراد مفتاح عام إلى الحاسب الفرعي</translation>
    </message>
    <message>
        <source>Create new access keys (master computer)</source>
        <translation>إنشاء مفاتيح وصول جديدة (الحاسب الرئيسي)‏</translation>
    </message>
    <message>
        <source>assistantModeButtonGroup</source>
        <translation>مجموعة أزر حالة المساعد</translation>
    </message>
    <message>
        <source>Import public key (client computer)</source>
        <translation>استيراد مفتاح عام (حاسب فرعي)‏</translation>
    </message>
    <message>
        <source>Select user role</source>
        <translation>إختيار دور المستخدم</translation>
    </message>
    <message>
        <source>Please select a user role for which to create or import the access keys:</source>
        <translation>يرجى إختيار دور المستخدم الذي ترغب في إنشاء أو استيراد مفاتيح وصول له. </translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation>مدرِّس</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation>المدير</translation>
    </message>
    <message>
        <source>Support team member</source>
        <translation>عضو فريق الدعم</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>آخر</translation>
    </message>
    <message>
        <source>User roles allow using multiple access keys in parallel. For example there can be different teacher access keys for each classroom while the support access keys are the same for the whole school.</source>
        <translation>تسمح أدوار المستخدم باستخدام عدة مفاتيح وصول بالتوازي. مثلا، يمكن تخصيص مفاتيح مختلفة لوصول المدرس لكل غرفة دراسة بينما تكون مفاتيح الوصول للدعم متشابهة لكل أعضاء المدرسة.</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation>أدلة </translation>
    </message>
    <message>
        <source>Export public key part (master computer)</source>
        <translation>تصدير جزء المفتاح العام (الحاسب الرئيسي)‏</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Use custom destination directory for access keys</source>
        <translation>استخدم دليل وجهة مخصص لمفاتيح الوصول </translation>
    </message>
    <message>
        <source>Please specify the location of the public access key to be imported.</source>
        <translation>يرجى تحديد موقع مفاتيح الوصول المطلوب استيرادها</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>ملخص</translation>
    </message>
    <message>
        <source>The following actions will be taken:</source>
        <translation>سيتم إتخاذ الإجراءات التالية</translation>
    </message>
    <message>
        <source>• Create new access keys</source>
        <translation>إنشاء مفاتيح وصول جديدة</translation>
    </message>
    <message>
        <source>• Import public access key from</source>
        <translation>استيراد مفتاح وصول عام من</translation>
    </message>
    <message>
        <source>&lt;unknown&gt;</source>
        <translation>&lt;غير معروف&gt;</translation>
    </message>
    <message>
        <source>• Write access key(s) to</source>
        <translation>مفتاح أو مفاتيح الوصول إلى الكتابة إلى </translation>
    </message>
    <message>
        <source>• Export public key to</source>
        <translation>تصدير مفتاح عام إلى</translation>
    </message>
    <message>
        <source>• Configure for user role</source>
        <translation>تهيئة دور المستخدم</translation>
    </message>
    <message>
        <source>Select directory in which to export the public key</source>
        <translation>إختيار الدليل الذي سيتم تصدير الملف إليه</translation>
    </message>
    <message>
        <source>Key files (*.key.txt)</source>
        <translation> (*.key.txt) ملفات رئيسية</translation>
    </message>
    <message>
        <source>Invalid public key</source>
        <translation>مفتاح عام غير صحيح</translation>
    </message>
    <message>
        <source>The selected file does not contain a valid public iTALC access key!</source>
        <translation>الملف المختار لا يحتوي مفتاح وصول عام صحيح لنظام &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>Select destination directory</source>
        <translation>اختيار دليل الوجهة</translation>
    </message>
    <message>
        <source>Access key creation</source>
        <translation>إنشاء مفتاح وصول</translation>
    </message>
    <message>
        <source>Could not remove previously existing file %1.</source>
        <translation>تعذر إزالة الملف 1% الموجود مسبقا</translation>
    </message>
    <message>
        <source>Failed exporting public access key from %1 to %2.</source>
        <translation>أخفقت عملية تصدير مفتاح الوصول العام من 1% إلى 2%‏</translation>
    </message>
    <message>
        <source>Access keys were created and written successfully to %1 and %2.</source>
        <translation>تم إنشاء مفاتيح الوصول بنجاح وكتابتها في 1% و 2%.</translation>
    </message>
    <message>
        <source>An error occured while creating the access keys. You probably are not permitted to write to the selected directories.</source>
        <translation>حدث خطأ أثناء عملية إنشاء مفاتيح الوصول. من المرجح أنه غير مسموح لك بالكتابة على الأدلة المختارة</translation>
    </message>
    <message>
        <source>Public key import</source>
        <translation>استيراد مفتاح عام</translation>
    </message>
    <message>
        <source>An error occured while importing the public access key. You probably are not permitted to read the source key or to write the destination file.</source>
        <translation>حدث خطأ أثناء عملية استيراد مفاتيح الوصول العام. من المرجح أنه غير مسموح لك بقراءة مفتاح المصدر أو الكتابة إلى ملف الوجهة. </translation>
    </message>
    <message>
        <source>The public key was successfully imported to %1.</source>
        <translation>تم استيراد المفتاح العام إلى 1% بنجاح</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>screen lock</source>
        <translation>قفل الشاشة</translation>
    </message>
</context>
<context>
    <name>LogonGroupEditor</name>
    <message>
        <source>Logon group editor</source>
        <translation>الدخول إلى محرر المجموعة</translation>
    </message>
    <message>
        <source>Please add the groups whose members should be allowed to access computers in your iTALC network.</source>
        <translation>يرجى إضافة المجموعات التي يجب السماح لأعضائها بالوصول إلى الحاسبات على شبكة &quot;آيتالك&quot; </translation>
    </message>
    <message>
        <source>All groups</source>
        <translation>جميع المجموعات</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Groups with iTALC privileges</source>
        <translation>مجموعات ذات صلاحيات على &quot;آيتالك&quot;</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>Actions</source>
        <translation>عمليات</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>General</source>
        <translation>عام</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>iTALC Management Console</source>
        <translation>كونسولة إدارة نظام &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>iTALC Server</source>
        <translation>خادم &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>Paths</source>
        <translation>مسارات</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>توثيق</translation>
    </message>
    <message>
        <source>iTALC Service</source>
        <translation>خدمة &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>Hide tray icon</source>
        <translation>إخفاء أيقونة الصينية</translation>
    </message>
    <message>
        <source>Autostart</source>
        <translation>التشغيل آليا</translation>
    </message>
    <message>
        <source>Additional arguments</source>
        <translation>حجج إضافية</translation>
    </message>
    <message>
        <source>Start service</source>
        <translation>بدء الخدمة </translation>
    </message>
    <message>
        <source>Stop service</source>
        <translation>إيقاف الخدمة</translation>
    </message>
    <message>
        <source>State:</source>
        <translation>بيان:‏</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>توقف</translation>
    </message>
    <message>
        <source>Logging</source>
        <translation>دخول</translation>
    </message>
    <message>
        <source>Log file directory</source>
        <translation>دليل ملف الدخول</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Log level</source>
        <translation>مستوى الدخول</translation>
    </message>
    <message>
        <source>Nothing</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>Only critical messages</source>
        <translation>فقط الرسائل الحرجة</translation>
    </message>
    <message>
        <source>Errors and critical messages</source>
        <translation>أخطاء ورسائل حرجة </translation>
    </message>
    <message>
        <source>Warnings and errors</source>
        <translation>تحذيرات وأخطاء </translation>
    </message>
    <message>
        <source>Information, warnings and errors</source>
        <translation>المعلومات، والتحذيرات والأخطاء</translation>
    </message>
    <message>
        <source>Debug messages and everything else</source>
        <translation>رسائل الأخطاء وما عداها</translation>
    </message>
    <message>
        <source>Limit log file size</source>
        <translation>تحديد حجم ملف الدخول</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>ام بي</translation>
    </message>
    <message>
        <source>Clear all log files</source>
        <translation>مسح كافة ملفات الدخول</translation>
    </message>
    <message>
        <source>Desktop capturing</source>
        <translation>إلتقاط صورة سطح المكتب</translation>
    </message>
    <message>
        <source>Enable capturing of layered (semi-transparent) windows</source>
        <translation>تمكين إلتقاط صورة نوافذ طبقية (شبه شفافة)‏</translation>
    </message>
    <message>
        <source>Low accuracy (turbo mode)</source>
        <translation>دقة منخفضة (وضعية تيربو)‏</translation>
    </message>
    <message>
        <source>Demo server</source>
        <translation>خادم العرض</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>شبكة</translation>
    </message>
    <message>
        <source>Core server port</source>
        <translation>منفذ الخادم الأساسي</translation>
    </message>
    <message>
        <source>Demo server port</source>
        <translation>منفذ خادم العرض </translation>
    </message>
    <message>
        <source>Enable firewall exception</source>
        <translation>تمكين إستثناء الجدار الناري</translation>
    </message>
    <message>
        <source>Configuration files</source>
        <translation>ملفات التهيئة</translation>
    </message>
    <message>
        <source>Global configuration</source>
        <translation>تهيئة عامة </translation>
    </message>
    <message>
        <source>Personal configuration</source>
        <translation>تهيئة شخصية </translation>
    </message>
    <message>
        <source>Data directories</source>
        <translation>أدلة البيانات</translation>
    </message>
    <message>
        <source>Snapshots</source>
        <translation>لقطات</translation>
    </message>
    <message>
        <source>Authentication methods</source>
        <translation>طرق التوثيق</translation>
    </message>
    <message>
        <source>Access key management</source>
        <translation>إدارة مفاتيح الوصول</translation>
    </message>
    <message>
        <source>Logon settings</source>
        <translation>إعدادات الدخول</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>‎‏&amp;‏ملف‏‎</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>‏&amp;مساعدة</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>‏&amp;خروج</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Save settings into file</source>
        <translation>‏&amp;حفظ الاعدادات في الملف‎‏‏</translation>
    </message>
    <message>
        <source>Save settings into file</source>
        <translation>حفظ الاعدادات في الملف</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>L&amp;oad settings from file</source>
        <translation>تحميل الاعدادات من الملف</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation>حول &quot;آيتالك&quot;</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>حول&quot;كيو تي&quot;</translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation>الشاشة الرئيسية</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation>شريط الأدوات</translation>
    </message>
    <message>
        <source>iTALC Management Console %1</source>
        <translation>كونسولة إدارة نظام &quot;آيتالك&quot; 1%‏</translation>
    </message>
    <message>
        <source>Running</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Load settings from file</source>
        <translation>تحميل الاعدادات من الملف</translation>
    </message>
    <message>
        <source>XML files (*.xml)</source>
        <translation>(*.xml) XML ملفات </translation>
    </message>
    <message>
        <source>Save settings to file</source>
        <translation>حفظ الاعدادات إلى الملف</translation>
    </message>
    <message>
        <source>Unsaved settings</source>
        <translation>إعدادات لم يتم حفظها</translation>
    </message>
    <message>
        <source>There are unsaved settings. Quit anyway?</source>
        <translation>هنالك إعدادات لم يتم حفظها. هل ترغب في الخروج على أي حال؟</translation>
    </message>
    <message>
        <source>Configuration not writable</source>
        <translation>تعيئة غير قابلة للكتابة</translation>
    </message>
    <message>
        <source>The local configuration backend reported that the configuration is not writable! Please run the iTALC Management Console with higher privileges.</source>
        <translation>يبدو ان ملف التهيئة المحلية الخلفي أن التهيئة غير قابلة للكتابة! يرجى تشغيل كونسولة إدارة &quot;آيتالك&quot; بصلاحيات عالية </translation>
    </message>
    <message>
        <source>All settings were applied successfully.</source>
        <translation>تم تطبيق كافة الإعدادات بنجاح</translation>
    </message>
    <message>
        <source>An error occured while applying settings!</source>
        <translation>حدث خطأ أثناء عملية تطبيق الإعدادات</translation>
    </message>
    <message>
        <source>iTALC</source>
        <translation>&quot;آيتالك&quot;</translation>
    </message>
    <message>
        <source>No write access</source>
        <translation>لا يوجد وصول للكتابة </translation>
    </message>
    <message>
        <source>Could not read/write or create directory %1! For running iTALC, make sure you&apos;re permitted to create or write this directory.</source>
        <translation>تعذر قراءة أوكتابة أو إنشاء دليل لـ 1%! لتشغيل &quot;آيتالك&quot; يرجى التأكد من أن لديك صلاحية إنشاء أو كتابة هذا الدليل. </translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation>غرفة دراسة</translation>
    </message>
    <message>
        <source>Switch classroom</source>
        <translation>تحويل غرفة الدراسة</translation>
    </message>
    <message>
        <source>Click this button to open a menu where you can choose the active classroom.</source>
        <translation>أنقر على هذا المفتاح، لفتح قائمة يمكنك منها إختيار الفصل النشط   </translation>
    </message>
    <message>
        <source>Click on this button, to switch between classrooms.</source>
        <translation>أنقر على هذا المفتاح، للتحول بين الفصول</translation>
    </message>
    <message>
        <source>Overview mode</source>
        <translation>وضع اللمحة العامة</translation>
    </message>
    <message>
        <source>Overview</source>
        <translation>لمحة عامة</translation>
    </message>
    <message>
        <source>This is the default mode in iTALC and allows you to have an overview over all visible computers. Also click on this button for unlocking locked workstations or for leaving demo-mode.</source>
        <translation>هذه هي الوضعية الافتراضية لنظام &quot;آيتالك&quot; وتمكنك من الاطلاع على كافة الحاسبات الظاهرة. أيضا أنقر على هذا الزر لفتح محطات العمل المغلقة أو الخروج من وضعية العرض التعريفي.</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation>عرض تعريفي ملء الشاشة</translation>
    </message>
    <message>
        <source>Fullscreen Demo</source>
        <translation>عرض تعريفي ملء الشاشة</translation>
    </message>
    <message>
        <source>Stop Demo</source>
        <translation>إيقاف العرض التعريفي</translation>
    </message>
    <message>
        <source>In this mode your screen is being displayed on all shown computers. Furthermore the users aren&apos;t able to do something else as all input devices are locked in this mode.</source>
        <translation>بهذا الوضع، يتم عرض شاشتك على نافذة على كافة الحاسبات الظاهرة. كما أنه لا يمكن للمستخدمين أداء عمل آخر إذ أن جميع الأجهزة تكون مغلقة في هذا الوضع.</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation>نافذة عرض تعريفي</translation>
    </message>
    <message>
        <source>Window Demo</source>
        <translation>نافذة عرض تعريفي</translation>
    </message>
    <message>
        <source>In this mode your screen being displayed in a window on all shown computers. The users are able to switch to other windows and thus can continue to work.</source>
        <translation>بهذا الوضع، يتم عرض شاشتك على نافذة على كافة الحاسبات الظاهرة. يمكن للمستخدمين التحول إلى نوافذ أخرى ومواصلة عملهم </translation>
    </message>
    <message>
        <source>Lock/unlock desktops</source>
        <translation>إغلاق أو فتح أسطح المكاتب</translation>
    </message>
    <message>
        <source>Lock all</source>
        <translation>إغلاق الجميع</translation>
    </message>
    <message>
        <source>Unlock all</source>
        <translation>فتح الجميع</translation>
    </message>
    <message>
        <source>To have all user&apos;s full attention you can lock their desktops using this button. In this mode all input devices are locked and the screen is black.</source>
        <translation>للفت إنتباه كافة المستخدمين، يمكنك إغلاق سطح المكتب لديهم باستخدام هذا الزر. في هذا الوضع، يتم قفل جميع أجهزة الإدخال وتصبح الشاشات سوداء.</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation>إرسال رسالة نصية</translation>
    </message>
    <message>
        <source>Text message</source>
        <translation>رسالة نصيِّة</translation>
    </message>
    <message>
        <source>Use this button to send a text message to all users e.g. to tell them new tasks etc.</source>
        <translation>استخدم هذا الزر لإرسال رسالة نصية لجميع المستخدمين، مثلا لإخطارهم بمهمة جديدة أو ما شابه.‏</translation>
    </message>
    <message>
        <source>Power on computers</source>
        <translation>تشغيل الحاسبات</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Click this button to power on all visible computers. This way you do not have to turn on each computer by hand.</source>
        <translation>أنقر هذا الزر لتشغيل جميع الحاسبات الظاهرة. بهذه الآلية، لن تحتاج إلى تشغيل كل حاسب يدويا </translation>
    </message>
    <message>
        <source>Power down computers</source>
        <translation>إطفاء الحاسبات</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation>إطفاء</translation>
    </message>
    <message>
        <source>To power down all shown computers (e.g. after the lesson has finished) you can click this button.</source>
        <translation>لإطفاء كافة الحاسبات الظاهرة (مثلا، بعد إنتهاء الدرس) يمكنك النقر على هذا الزر.‏</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>الدعم</translation>
    </message>
    <message>
        <source>Direct support</source>
        <translation>دعم مباشر</translation>
    </message>
    <message>
        <source>If you need to support someone at a certain computer you can click this button and enter the according hostname or IP afterwards.</source>
        <translation>إذا رغبت في دعم أحد المستخدمين لحاسب معين يمكنك النقر على هذا الزر وادخال اسم المضيف أو عنوان IP بعد ذلك.</translation>
    </message>
    <message>
        <source>Adjust/align</source>
        <translation>ضبط  أو محاذاة</translation>
    </message>
    <message>
        <source>Adjust windows and their size</source>
        <translation>قم بضبط النوافذ ومقاسها</translation>
    </message>
    <message>
        <source>When clicking this button the biggest possible size for the client-windows is adjusted. Furthermore all windows are aligned.</source>
        <translation>عند النقر على هذا الزر، يتم ضبط نوافذ الحاسب الفرعي على أكبر مقاس ممكن لها. كما تتم محاذاة جميع النوافذ.‏</translation>
    </message>
    <message>
        <source>Auto view</source>
        <translation>معاينة آلية</translation>
    </message>
    <message>
        <source>Auto re-arrange windows and their size</source>
        <translation>إعادة ترتيب النوافذ ومقاساتها آليا</translation>
    </message>
    <message>
        <source>When clicking this button all visible windows are re-arranged and adjusted.</source>
        <translation>عند النقر على هذا الزر، تتم إعادة ترتيب وضبط كافة النوافذ الظاهرة.‏</translation>
    </message>
    <message>
        <source>iTALC Master Control</source>
        <translation>التحكم الرئيسي في &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>تحكم من بُعد</translation>
    </message>
    <message>
        <source>Could not modify the autostart property for the iTALC Service.</source>
        <translation>تعذر تعديل خاصية التشغيل الآلي لنظام &quot;آيتالك&quot;</translation>
    </message>
    <message>
        <source>Could not modify the service arguments for the iTALC Service.</source>
        <translation>تعذر تعديل خاصية حجج الخدمة لنظام &quot;آيتالك&quot;</translation>
    </message>
    <message>
        <source>Could not change the firewall configuration for the iTALC Service.</source>
        <translation>تعذر تغيير تهيئة الجدار الناري لنظام &quot;آيتالك&quot; </translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>إزالة الأخطاء </translation>
    </message>
    <message>
        <source>Enable desktop switching for screen lock (experimental)</source>
        <translation>تمكين تحويل سطح المكتب لقفل الشاشة (تجريبي)‏</translation>
    </message>
    <message>
        <source>Log to standard error output</source>
        <translation>الدخول إلى خرج الاخطاء القياسية</translation>
    </message>
    <message>
        <source>Log to Windows event log</source>
        <translation>الدخول إلى نافذة احداث وندوز</translation>
    </message>
    <message>
        <source>Backend</source>
        <translation>خلفي</translation>
    </message>
    <message>
        <source>VNC reflector</source>
        <translation>VNC عاكس</translation>
    </message>
    <message>
        <source>iTALC 1 demo server</source>
        <translation>خادم العرض 1 &quot;آيتالك&quot;</translation>
    </message>
    <message>
        <source>Multithreading (can be enabled when using the VNC reflector backend)</source>
        <translation>مسارات تنفيذ متعددة (يمكن تفعيلها عند استخدام ملف شبكة الحوسبة الإلكترونية الخلفي)‏</translation>
    </message>
    <message>
        <source>Enable HTTP server which provides a JavaViewer applet</source>
        <translation>تمكين خادم HTTP الذي يوفر عارض تطبيقات جافا </translation>
    </message>
    <message>
        <source>HTTP server port</source>
        <translation>تقرير خادم HTTP</translation>
    </message>
    <message>
        <source>Allow connections from localhost only</source>
        <translation>السماح بالتوصيل من المضيف المحلي فقط</translation>
    </message>
    <message>
        <source>Key file authentication</source>
        <translation>توثيق ملف المفاتيح</translation>
    </message>
    <message>
        <source>ACL-based logon authentication</source>
        <translation>توثيق الدخول استنادا على قائمة التحكم في الوصول</translation>
    </message>
    <message>
        <source>Public key file base directory</source>
        <translation>دليل ملفات المفاتيح العامة الأساسي </translation>
    </message>
    <message>
        <source>Private key file base directory</source>
        <translation>دليل ملفات المفاتيح الخاصة الأساسي </translation>
    </message>
    <message>
        <source>Launch key file assistant</source>
        <translation>تشغيل مساعد  ملف المفاتيح</translation>
    </message>
    <message>
        <source>Manage permissions</source>
        <translation>صلاحيات الإدارة </translation>
    </message>
    <message>
        <source>Test</source>
        <translation>إختبار</translation>
    </message>
    <message>
        <source>Access confirmation</source>
        <translation>تأكيد الوصول</translation>
    </message>
    <message>
        <source>You can configure iTALC to ask the user for permission to access the desktop when using certain authentication methods.</source>
        <translation>يمكن تهيئة &quot;آيتالك&quot; بحيث يمكنك طلب السماح من المستخدم للوصول إلى سطح مكتبه عند استخدام طرق توثيق معينة.‏</translation>
    </message>
    <message>
        <source>Logon authentication</source>
        <translation>توثيق الدخول</translation>
    </message>
    <message>
        <source>Allow same user to access desktop without confirmation</source>
        <translation>السماح لذات المستخدم من الوصول إلى  سطح المكتب دون تأكيد. </translation>
    </message>
    <message>
        <source>Debugging iTALC</source>
        <translation>إزالة الأخطاء من &quot;آيتالك&quot;</translation>
    </message>
    <message>
        <source>When encountering bugs or other misbehaviour in iTALC it is important to inform the developers about them, so that the bugs can be fixed in future releases. This page allows you to submit a helpful bug report easily.

If the bug is not reproducible, skip step 1) - 3).</source>
        <translation>عند مواجهة أخطاء أو سوء تشغيل في &quot;آيتالك&quot; فمن الضروري إخطار المطورين عنهاحتى تتم معالجة الاخطاء في الإصدارات اللاحقة. هذه الصفحة تمكنك من رفع تقرير أخطاء مفيد بكل سهولة.

إذا كان الخطأ غير قابل للنسخ، تجاوز الخطوة 1 الى 3</translation>
    </message>
    <message>
        <source>1)</source>
        <translation>1)</translation>
    </message>
    <message>
        <source>Clear the logfiles in the &quot;General&quot; section.</source>
        <translation> مسح ملفات الدخول في القسم &quot;عام&quot;‏</translation>
    </message>
    <message>
        <source>2)</source>
        <translation>2)</translation>
    </message>
    <message>
        <source>In the &quot;General&quot; section set the log level to &quot;Debug messages and everything else&quot;.</source>
        <translation> في قسم &quot;عام&quot; قم بضبط مستوى الدخول عند &quot;رسائل إزالة الأخطاء وغيرها&quot;‏‎‍‎‏‎</translation>
    </message>
    <message>
        <source>3)</source>
        <translation>3)</translation>
    </message>
    <message>
        <source>Repeat the actions leading to the bug or misbehaviour.</source>
        <translation> تكرار الإجراءات المؤدية إلى الخطأ أو سوء الأداء  </translation>
    </message>
    <message>
        <source>4)</source>
        <translation>4)</translation>
    </message>
    <message>
        <source>Click the following button and save the file to a known location.</source>
        <translation> أنقر هذا الزر لحفظ الملف في وجهة معروفة</translation>
    </message>
    <message>
        <source>Generate bug report archive</source>
        <translation>إنتاج ارشيف تقارير أخطاء</translation>
    </message>
    <message>
        <source>5)</source>
        <translation>5)</translation>
    </message>
    <message>
        <source>Go to the &lt;a href=&quot;http://sourceforge.net/tracker/?group_id=132465&amp;amp;atid=724375&quot;&gt;iTALC bug tracker&lt;/a&gt;, open a new bug, describe what you did in step 3) and attach the file you saved in step 4).&lt;/p&gt;
&lt;br/&gt;
&lt;br/&gt;
Note: if the bug involves both a master and client computer, attach bug report archives for both computers.</source>
        <translation>اذهب إلى http://sourceforge.net/tracker/?group_id=132465&amp;amp;atid=724375&quot; للوصول إلى راصد أخطاء&quot;آيتالك&quot;، افتح ملف أخطاء جديد، صف ما قمت به في الخطوة 3 ثم أرفق الملف الذي حفظته في 


ملحوظة: إذا كان الخطأ يشمل حاسب رئيسي وحاسب فرعي، قم بإلحاق أرشيف تقرير الأخطاء لكلا الحاسبين. </translation>
    </message>
    <message>
        <source>Restart iTALC Service</source>
        <translation>إعادة تشغيل خدمة &quot;آيتالك&quot; </translation>
    </message>
    <message>
        <source>All settings were saved successfully. In order to take effect the iTALC service needs to be restarted. Restart it now?</source>
        <translation>تم حفظ كافة الإعدادات بنجاح. لتفعيلها يلزم إعادة تشغيل آيتالك&quot;. هل ترغب في إعادة التشغيل الآن؟</translation>
    </message>
    <message>
        <source>Starting iTALC service</source>
        <translation>بدء خدمة &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>Stopping iTALC service</source>
        <translation>إيقاف خدمة &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>The iTALC service needs to be stopped temporarily in order to remove the log files. Continue?</source>
        <translation>تحتاج خدمة &quot;آيتالك&quot; للإيقاف الموقت لأجل إزالة ملفات الدخول. هل ترغب في الاستمرار</translation>
    </message>
    <message>
        <source>Log files cleared</source>
        <translation>مسح ملفات الدخول</translation>
    </message>
    <message>
        <source>All log files were cleared successfully.</source>
        <translation>تمت إزالة جميع ملفات الدخول بنجاح</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <source>Could not remove all log files.</source>
        <translation>تعذرت إزالة كافة ملفات الدخول</translation>
    </message>
    <message>
        <source>Logon authentication test</source>
        <translation>إختبار توثيق الدخول</translation>
    </message>
    <message>
        <source>Authentication with provided credentials was successful.</source>
        <translation>نجحت عملية التوثيق عبر بيانات التوثيق المقدمة </translation>
    </message>
    <message>
        <source>Authentication with provided credentials failed!</source>
        <translation>أخفقت عملية التوثيق عبر بيانات التوثيق المقدمة </translation>
    </message>
    <message>
        <source>Save bug report archive</source>
        <translation>حفظ أرشيف تقارير الأخطاء </translation>
    </message>
    <message>
        <source>iTALC bug report archive (*.ibra.xml)</source>
        <translation> لنظام &quot;آيتالك&quot;‏(*.ibra.xml) أرشيف تقارير الاخطاء  </translation>
    </message>
    <message>
        <source>iTALC bug report archive saved</source>
        <translation>تم حفظ أرشيف تقارير الاخطاء لنظام &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>An iTALC bug report archive has been saved to %1. It includes iTALC log files and information about your operating system. You can attach it to a bug report.</source>
        <translation>تم حفظ تقرير أرشيفي لأخطاء &quot;آيتالك&quot; على 1%. وهو يحتوي على ملفات دخول &quot;آيتالك&quot; ومعلومات عن نظام التشغيل لديك. يمكنك إلحاقه بتقرير أخطاء. </translation>
    </message>
    <message>
        <source>Could not contact iTALC service</source>
        <translation>تعذر الاتصال بنظام &quot;آيتالك&quot;</translation>
    </message>
    <message>
        <source>Could not contact the local iTALC service. It is likely that you entered wrong credentials or key files are not set up properly. Try again or contact your administrator for solving this problem using the iTALC Management Console.</source>
        <translation>تعذر الاتصال بنظام &quot;آيتالك&quot; المحلي. من المرجح إنك أدخلت بيانات توثيق خاطئة، او أن الملفات لم يتم إنشاؤها بطريقة صحيحة. حاول ثانية أو اتصل بمدير النظام لحل هذه المشكلة باستخدام كنسولة إدارة &quot;آيتالك&quot;. ‏</translation>
    </message>
    <message>
        <source>Authentication impossible</source>
        <translation>يتعذر التوثيق</translation>
    </message>
    <message>
        <source>No authentication key files were found or your current ones are outdated. Please create new key files using the iTALC Management Console. Alternatively set up logon authentication using the iTALC Management Console. Otherwise you won&apos;t be able to access computers using iTALC.</source>
        <translation>تعذر العثور على ملفات مفاتيح التوثيق أو أن ملفاتك الحالية قديمة. يرجى إنشاء ملفات مفاتيح جديدة باستخدام كونسولة إدارة نظام &quot;آيتالك&quot;. عوضا عن ذلك، قم باعداد توثيق الدخول باستخدام كونسولة إدارة نظام &quot;آيتالك&quot;، وإلا سوف </translation>
    </message>
    <message>
        <source>Poll full screen (leave this enabled per default)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageBoxSlave</name>
    <message>
        <source>Message from teacher</source>
        <translation>رسالة من المدرس </translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Welcome to iTALC!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>مرحبا بك إلى &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>Here you see the working-bar which contains several buttons. Each button is connected to a workspace. Just take a look at the available workspaces by clicking on the corresponding button.</source>
        <translation>هنا يمكنك رؤية شريط العمل الذي يحتوي على عدة أزر. كل زر متصل بمساحة عمل معينة. يمكنك معاينة مساحات العمل المتاحة عبر النقر على الزر المقابل.</translation>
    </message>
    <message>
        <source>Using the classroom-manager you can manage your classrooms and computers. You can also see which users are logged in.</source>
        <translation>باستخدام مدير غرفة الدراسة يمكنك إدارة غرفك الدراسية وحاسباتها. كما يمكنك أيضا معاينة المستخدمين الداخلين على النظام.‏</translation>
    </message>
    <message>
        <source>The snapshot-workspace is a very useful tool. It let&apos;s you manage the snapshots you made.</source>
        <translation>إن مساحة عمل اللقطات هي أداة هامة. فهي تمكنك  من إدارة اللقطات التي أخذتها.‏</translation>
    </message>
    <message>
        <source>Of course you can configure iTALC. This is usually done using the configuration-workspace.</source>
        <translation>يمكنك، بالطبع، تهيئة &quot;آيتالك&quot;. يتم القيام عادة بذلك باستخدام مساحة عمل التهيئة.‏</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation>حول &quot;آيتالك&quot;‏</translation>
    </message>
</context>
<context>
    <name>OverviewWidget</name>
    <message>
        <source>Overview</source>
        <translation>لمحة عامة</translation>
    </message>
    <message>
        <source>Some basic information on iTALC and how to use it.</source>
        <translation>بعض المعلومات الأساسية حول &quot;آيتالك&quot; وكيفية استخدامه.‏</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Please enter your username and password in order to access iTALC clients.</source>
        <translation>يرجى إدخالك اسم المستخدم وكلمة السر الخاصين بك للوصول إلى الحاسبات الفرعية لنظام &quot;آيتالك&quot;.‏</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة السر</translation>
    </message>
    <message>
        <source>iTALC Logon</source>
        <translation>الدخول إلى &quot;آيتالك&quot;‏</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation>غير قادر على تسجيل الخدمة 1%‏</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation>تعذر الاتصال بمدير التحكم في الخدمة (هل لديك الصلاحيات اللازمة؟) - لم يتم تسجيل الخدمة 1%.‏</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation>الخدمة 1% مسجلة مسبقا</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation>تعذر تسجيل الخدمة 1% ‏</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation>تم تسجيل الخدمة 1% بنجاح</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation>تعذر إيقاف الخدمة 1% ‏</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation>تم إلغاء تسجيل الخدمة 1% ‏</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation>الخدمة 1% غير مسجلة وبالتالي لا يمكن إلغاء تسجيلها</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation>تعذر إلغاء تسجيل الخدمة 1% ‏</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation>تعذر العثور على الخدمة 1% </translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation>تعذر الاتصال بمدير التحكم في الخدمة (هل لديك الصلاحيات اللازمة؟) - لم يتم إلغاءتسجيل الخدمة 1%.‏</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation>تعذر الاتصال بمدير التحكم في الخدمة (هل لديك الصلاحيات اللازمة؟) - لم يتم إيقاف الخدمة 1%.‏</translation>
    </message>
    <message>
        <source>iTALC Client %1 on %2:%3</source>
        <translation>الحاسب الفرعي 1% لنظام &quot;آيتالك&quot; على 2% و3%‏</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidget</name>
    <message>
        <source>View live (%1 @ %2)</source>
        <translation>معاينة حية (1% @ 2%)‏</translation>
    </message>
    <message>
        <source>Remote control (%1 @ %2)</source>
        <translation>تحكم من بُعد (1% @ 2%)‏</translation>
    </message>
    <message>
        <source>unknown user</source>
        <translation>مستخدم غير معروف</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidgetToolBar</name>
    <message>
        <source>View only</source>
        <translation>معاينة فقط</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>تحكم من بُعد</translation>
    </message>
    <message>
        <source>Lock student</source>
        <translation>غلق الطالب</translation>
    </message>
    <message>
        <source>Unlock student</source>
        <translation>فتح الطالب</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>لقطة</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ملء الشاشة</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>نافذة</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Connecting %1</source>
        <translation>توصيل 1%‏</translation>
    </message>
    <message>
        <source>Connected.</source>
        <translation>متصل</translation>
    </message>
</context>
<context>
    <name>RemoteLogonDialog</name>
    <message>
        <source>Remote logon</source>
        <translation>دخول من بُعد</translation>
    </message>
    <message>
        <source>Use the fields below to enter the username, password and optional the domain name. These information will be used to logon the computer(s).</source>
        <translation>استخدم هذا الحقل لادخال اسم المستخدم وكلمة السر وإختياريا اسم النطاق. سيتم استخدام هذه المعلومات للدخول إلى الحاسب أو الحاسبات</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>كلمة السر</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>النطاق</translation>
    </message>
</context>
<context>
    <name>RunCommandsDialog</name>
    <message>
        <source>Run commands</source>
        <translation>تشغيل الأوامر</translation>
    </message>
    <message>
        <source>Please enter the commands to run on the selected client(s). You can separate multiple commands by line.</source>
        <translation>يرجى إدخال الأوامر المطلوب تشغيلها على الحاسب أو الحاسبات الفرعية. يمكنك الفصل بين الأوامر المتعددة باستخدام أسطر متعددة</translation>
    </message>
</context>
<context>
    <name>Snapshot</name>
    <message>
        <source>unknown</source>
        <translation>غير معروف</translation>
    </message>
    <message>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation>تعذر أخذ لقطة إذ أن الدليل 1% غير موجود ولا يمكن إنشاؤه </translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>لقطة</translation>
    </message>
</context>
<context>
    <name>SnapshotList</name>
    <message>
        <source>Snapshots</source>
        <translation>لقطات</translation>
    </message>
    <message>
        <source>Simply manage the snapshots you made using this workspace.</source>
        <translation>قم ببساطة بمعالجة اللقطات التي أخذتها باستخدام مساحة العمل هذه.</translation>
    </message>
</context>
<context>
    <name>Snapshots</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;All snapshots you made are listed here. You can make snapshots by selecting the according entry in the context-menu of a client-window. These snapshosts can be managed using the buttons below.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>كافة اللقطات التي أخذتها موجودة هنا. يمكنك أخذ لقطات باختيار الدخول الملائم من قائمة السياق على نافذة الحاسب الفرعي. هذه اللقطات يمكن إدارتها باستخدام الأزرار أدناه. </translation>
    </message>
    <message>
        <source>User:</source>
        <translation>المستخدم</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>مضيف</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>التاريخ</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>الزمن</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
</context>
<context>
    <name>SupportDialog</name>
    <message>
        <source>Support</source>
        <translation>دعم</translation>
    </message>
    <message>
        <source>Please enter the IP address or the name of the host to which you want to connect.</source>
        <translation>يرجى إدخال عنوان IP أو اسم المضيف الذي ترغب في الاتصال به</translation>
    </message>
</context>
<context>
    <name>TextMessageDialog</name>
    <message>
        <source>Send text message</source>
        <translation>إرسال رسالة نصية</translation>
    </message>
    <message>
        <source>Use the field below to type your message which will be sent to all selected users.</source>
        <translation>استخدم الحقل أدناه لطباعة رسالتك التي سيتم ارسالها الى كافة المستخدمين المختارين</translation>
    </message>
</context>
<context>
    <name>VncView</name>
    <message>
        <source>Establishing connection to %1 ...</source>
        <translation>انشاء اتصال بـ 1%</translation>
    </message>
</context>
<context>
    <name>clientMenu</name>
    <message>
        <source>Overview</source>
        <translation>لمحة عامة</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation>عرض على كامل الشاشة</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation>عرض على نافذة</translation>
    </message>
    <message>
        <source>Locked display</source>
        <translation>شاشة مغلقة</translation>
    </message>
    <message>
        <source>View live</source>
        <translation>معاينة حيّة</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>تحكم من بُعد</translation>
    </message>
    <message>
        <source>Let student show demo</source>
        <translation>السماح للطالب بالعرض</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation>إرسال رسالة نصية</translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation>إخراج المستخدم</translation>
    </message>
    <message>
        <source>Take a snapshot</source>
        <translation>أخذ لقطة</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation>تشغيل </translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>إعادة تشغيل الحاسب </translation>
    </message>
    <message>
        <source>Power down</source>
        <translation>إطفاء </translation>
    </message>
    <message>
        <source>Execute commands</source>
        <translation>تنفيذ الأوامر </translation>
    </message>
</context>
</TS>
